@@ -16,7 +16,7 @@ checkfail()
 # ARGUMENTS #
 #############
 
-MEDIALIBRARY_HASH=13241cd5
+MEDIALIBRARY_HASH=175cd2e9
 
 RELEASE=0
 ASAN=0
@@ -325,16 +325,16 @@ fi
 # stub libraries
 CROSS_TOOLS=${NDK_TOOLCHAIN_PATH}/${TARGET_TUPLE}-
 
-export PATH=${NDK_TOOLCHAIN_PATH}:${PATH}
+export PATH="${NDK_TOOLCHAIN_PATH}:${PATH}"
 if [ ! -z "$MSYSTEM_PREFIX" ] ; then
     # The make.exe and awk.exe from the toolchain don't work in msys
-    export PATH=$MSYSTEM_PREFIX/bin:/usr/bin:${NDK_TOOLCHAIN_PATH}:${PATH}
+    export PATH="$MSYSTEM_PREFIX/bin:/usr/bin:${NDK_TOOLCHAIN_PATH}:${PATH}"
 fi
 
 ON_WINDOWS=0
 if [ ! -z "$MSYSTEM_PREFIX" ] ; then
     # The make.exe and awk.exe from the toolchain don't work in msys
-    export PATH=$MSYSTEM_PREFIX/bin:/usr/bin:${NDK_TOOLCHAIN_PATH}:${PATH}
+    export PATH="$MSYSTEM_PREFIX/bin:/usr/bin:${NDK_TOOLCHAIN_PATH}:${PATH}"
     ON_WINDOWS=1
 fi
 
@@ -453,7 +453,7 @@ cd vlc
 # Build buildsystem tools #
 ###########################
 
-export PATH=`pwd`/extras/tools/build/bin:$PATH
+export PATH="`pwd`/extras/tools/build/bin:$PATH"
 echo "Building tools"
 cd extras/tools
 ./bootstrap
