@@ -28,21 +28,21 @@ import android.database.Cursor;
 import android.graphics.Bitmap;
 import android.graphics.Bitmap.CompressFormat;
 import android.graphics.BitmapFactory;
-import android.graphics.drawable.BitmapDrawable;
 import android.media.RingtoneManager;
 import android.net.Uri;
 import android.provider.MediaStore;
-import android.support.annotation.RequiresPermission;
+import android.text.TextUtils;
 import android.util.Log;
 import android.widget.Toast;
 
 import org.videolan.libvlc.util.AndroidUtil;
+import org.videolan.medialibrary.media.MediaWrapper;
 import org.videolan.vlc.BuildConfig;
 import org.videolan.vlc.R;
 import org.videolan.vlc.VLCApplication;
 import org.videolan.vlc.media.MediaUtils;
-import org.videolan.vlc.media.MediaWrapper;
 import org.videolan.vlc.util.AndroidDevices;
+import org.videolan.vlc.util.HttpImageLoader;
 import org.videolan.vlc.util.MurmurHash;
 import org.videolan.vlc.util.Permissions;
 import org.videolan.vlc.util.Util;
@@ -60,6 +60,7 @@ import java.security.NoSuchAlgorithmException;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.LinkedList;
+import java.util.concurrent.atomic.AtomicReference;
 
 public class AudioUtil {
     public final static String TAG = "VLC/AudioUtil";
@@ -67,23 +68,20 @@ public class AudioUtil {
     /**
      * Cache directory (/sdcard/Android/data/...)
      */
-    public static String CACHE_DIR = null;
+    private static String CACHE_DIR = null;
     /**
      * VLC embedded art storage location
      */
-    public static String ART_DIR = null;
+    private static AtomicReference<String> ART_DIR = new AtomicReference<>();
     /**
      * Cover caching directory
      */
-    public static String COVER_DIR = null;
-    /**
-     * User-defined playlist storage directory
-     */
-    public static String PLAYLIST_DIR = null;
+    private static AtomicReference<String> COVER_DIR = new AtomicReference<>();
+//    /**
+//     * User-defined playlist storage directory
+//     */
+//    public static AtomicReference<String> PLAYLIST_DIR = new AtomicReference<>();
 
-    public static final BitmapDrawable DEFAULT_COVER = new BitmapDrawable(VLCApplication.getAppResources(), BitmapCache.getFromResource(VLCApplication.getAppResources(), R.drawable.icon));
-
-    @RequiresPermission(android.Manifest.permission.WRITE_SETTINGS)
     public static void setRingtone(MediaWrapper song, Activity context){
         if (!Permissions.canWriteSettings(context)) {
             Permissions.checkWriteSettingsPermission(context, Permissions.PERMISSION_SYSTEM_RINGTONE);
@@ -132,28 +130,32 @@ public class AudioUtil {
     }
 
     @SuppressLint("NewApi")
-    public static void prepareCacheFolder(Context context) {
-        try {
-            if (AndroidUtil.isFroyoOrLater() && AndroidDevices.hasExternalStorage() && context.getExternalCacheDir() != null)
-                CACHE_DIR = context.getExternalCacheDir().getPath();
-            else
-                CACHE_DIR = AndroidDevices.EXTERNAL_PUBLIC_DIRECTORY + "/Android/data/" + BuildConfig.APPLICATION_ID + "/cache";
-        } catch (Exception e) { // catch NPE thrown by getExternalCacheDir()
-            CACHE_DIR = AndroidDevices.EXTERNAL_PUBLIC_DIRECTORY + "/Android/data/" + BuildConfig.APPLICATION_ID + "/cache";
-        }
-        ART_DIR = CACHE_DIR + "/art/";
-        COVER_DIR = CACHE_DIR + "/covers/";
-        PLAYLIST_DIR = CACHE_DIR + "/playlists/";
-
-        for(String path : Arrays.asList(ART_DIR, COVER_DIR)) {
-            File file = new File(path);
-            if (!file.exists())
-                file.mkdirs();
-        }
+    public static void prepareCacheFolder(final Context context) {
+        VLCApplication.runBackground(new Runnable() {
+            @Override
+            public void run() {
+                try {
+                    if (AndroidDevices.hasExternalStorage() && context.getExternalCacheDir() != null)
+                        CACHE_DIR = context.getExternalCacheDir().getPath();
+                    else
+                        CACHE_DIR = AndroidDevices.EXTERNAL_PUBLIC_DIRECTORY + "/Android/data/" + BuildConfig.APPLICATION_ID + "/cache";
+                } catch (Exception e) { // catch NPE thrown by getExternalCacheDir()
+                    CACHE_DIR = AndroidDevices.EXTERNAL_PUBLIC_DIRECTORY + "/Android/data/" + BuildConfig.APPLICATION_ID + "/cache";
+                }
+                ART_DIR.set(CACHE_DIR + "/art/");
+                COVER_DIR.set(CACHE_DIR + "/covers/");
+//        PLAYLIST_DIR.set(CACHE_DIR + "/playlists/");
+                for(String path : Arrays.asList(ART_DIR.get(), COVER_DIR.get())) {
+                    File file = new File(path);
+                    if (!file.exists())
+                        file.mkdirs();
+                }
+            }
+        });
     }
 
     public static void clearCacheFolders() {
-        for(String path : Arrays.asList(ART_DIR, COVER_DIR)) {
+        for(String path : Arrays.asList(ART_DIR.get(), COVER_DIR.get())) {
             File file = new File(path);
             if (file.exists())
                 deleteContent(file, false);
@@ -222,10 +224,10 @@ public class AudioUtil {
                     titleHash = "0" + titleHash;
                 }
                 /* Use generated hash to find art */
-                artworkURL = ART_DIR + "/arturl/" + titleHash + "/art.png";
+                artworkURL = ART_DIR.get() + "/arturl/" + titleHash + "/art.png";
             } else {
                 /* Otherwise, it was cached by artist and album */
-                artworkURL = ART_DIR + "/artistalbum/" + mArtist + "/" + mAlbum + "/art.png";
+                artworkURL = ART_DIR.get() + "/artistalbum/" + mArtist + "/" + mAlbum + "/art.png";
             }
 
             return artworkURL;
@@ -281,15 +283,20 @@ public class AudioUtil {
 
     private static String getCoverCachePath(Context context, MediaWrapper media, int width) {
         final int hash = MurmurHash.hash32(MediaUtils.getMediaArtist(context, media) + MediaUtils.getMediaAlbum(context, media));
-        return COVER_DIR + (hash >= 0 ? "" + hash : "m" + (-hash)) + "_" + width;
+        return COVER_DIR.get() + (hash >= 0 ? "" + hash : "m" + (-hash)) + "_" + width;
     }
 
     public static Bitmap getCoverFromMemCache(Context context, MediaWrapper media, int width) {
+        Bitmap cover = null;
+
         if (media != null && media.getArtist() != null && media.getAlbum() != null) {
             final BitmapCache cache = BitmapCache.getInstance();
-            return cache.getBitmapFromMemCache(getCoverCachePath(context, media, width));
-        } else
-            return null;
+            cover = cache.getBitmapFromMemCache(getCoverCachePath(context, media, width));
+        }
+        if (cover == null && media != null && !TextUtils.isEmpty(media.getArtworkURL()) && media.getArtworkURL().startsWith("http")) {
+            cover = HttpImageLoader.getBitmapFromIconCache(media.getArtworkURL());
+        }
+        return cover;
     }
 
     @SuppressLint("NewApi")
@@ -324,10 +331,8 @@ public class AudioUtil {
                 if (cacheFile.exists()) {
                     if (cacheFile.length() > 0)
                         coverPath = cachePath;
-                    else
-                        return null;
                 }
-            }
+            } else
 
             // try to get it from VLC
             if (coverPath == null || !cacheFile.exists())
@@ -372,10 +377,13 @@ public class AudioUtil {
         }
     }
 
-    private static Bitmap readCoverBitmap(String path, int dipWidth) {
+    public static Bitmap readCoverBitmap(String path, int width) {
+        if (path == null)
+            return null;
+        if (path.startsWith("file"))
+            path = path.substring(7);
         Bitmap cover = null;
         BitmapFactory.Options options = new BitmapFactory.Options();
-        int width = UiTools.convertDpToPx(dipWidth);
 
         /* Get the resolution of the bitmap without allocating the memory */
         options.inJustDecodeBounds = true;
@@ -386,13 +394,15 @@ public class AudioUtil {
             options.inSampleSize = 1;
 
             // Find the best decoding scale for the bitmap
-            while( options.outWidth / options.inSampleSize > width)
-                options.inSampleSize = options.inSampleSize * 2;
+            if (width > 0) {
+                while (options.outWidth / options.inSampleSize > width)
+                    options.inSampleSize = options.inSampleSize * 2;
+            }
 
             // Decode the file (with memory allocation this time)
             cover = BitmapFactory.decodeFile(path, options);
+            BitmapCache.getInstance().addBitmapToMemCache(path, cover);
         }
-
         return cover;
     }
 
